<?php

namespace Drupal\theme_selector\Entity;

use Drupal\Core\Messenger\MessengerTrait;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\theme_selector\ThemeSelectorInterface;
use Drupal\Core\Config\Entity\ConfigEntityBase;

/**
 * Defines the Theme Selector entity.
 *
 * @ConfigEntityType(
 *   id = "theme_selector",
 *   label = @Translation("Theme Selector"),
 *   handlers = {
 *    "list_builder" = "Drupal\theme_selector\Controller\ThemeSelectorListBuilder",
 *    "form" = {
 *       "add-form" = "Drupal\theme_selector\Form\ThemeSelectorForm",
 *       "edit-form" = "Drupal\theme_selector\Form\ThemeSelectorForm",
 *       "delete-form" = "Drupal\theme_selector\Form\ThemeSelectorDeleteForm",
 *      },
 *    },
 *   config_prefix = "theme_selector",
 *   links = {
 *     "edit-form" = "/admin/config/user-interface/theme-selector/{theme_selector}/edit",
 *     "delete-form" = "/admin/config/user-interface/theme-selector/{theme_selector}/delete",
 *   },
 *   admin_permission = "administrater theme selector",
 *   entity_keys = {
 *     "title" = "title",
 *     "id" = "id",
 *     "sufix" = "sufix",
 *     "theme" = "theme"
 *   },
 *   config_export = {
 *     "id",
 *     "title",
 *     "sufix",
 *     "theme",
 *   }
 * )
 */
class ThemeSelectorEntity extends ConfigEntityBase implements ThemeSelectorInterface {

  use StringTranslationTrait, MessengerTrait;

  /**
   * Theme Selector entity id.
   *
   * @var string
   */
  protected $id;

  /**
   * Theme Selector entity title.
   *
   * @var string
   */
  protected $title;

  /**
   * Node title.
   *
   * @var string
   */

  /**
   * Returns the entity title.
   *
   * @return string
   *   The entity title.
   */
  public function getTitle() {
    return $this->get('title');
  }

  /**
   * Sets the entity title.
   *
   * @param string $title
   *   Node title.
   *
   * @return $this
   *   The Theme Selector entity.
   */
  public function setTitle($title) {
    $this->set('title', $title);
    return $this;
  }

  /**
   * Returns the entity title.
   *
   * @return string
   *   The entity title.
   */
  public function getSufix() {
    return $this->get('id');
  }

  /**
   * Sets the entity title.
   *
   * @param string $title
   *   Node title.
   *
   * @return $this
   *   The Theme Selector entity.
   */
  public function setSufix($sufix) {
    $this->set('id', $sufix);
    return $this;
  }

  /**
   * Returns the entity title.
   *
   * @return string
   *   The entity title.
   */
  public function getTheme() {
    return $this->get('theme');
  }

  /**
   * Sets the entity title.
   *
   * @param string $title
   *   Node title.
   *
   * @return $this
   *   The Theme Selector entity.
   */
  public function setTheme($theme) {
    $this->set('theme', $theme);
    return $this;
  }

  /**
   * Show a message accordingly to status, after creating/updating an entity.
   *
   * @param int $status
   *   Status int, returned after creating/updating an entity.
   */
  public function statusMessage($status) {
    if ($status) {
      $this->messenger()->addMessage($this->t('Saved the %label entity.', ['%label' => $this->getTitle()]));
    }
    else {
      $this->messenger()->addMessage($this->t('The %label entity was not saved.', ['%label' => $this->getTitle()]));
    }
  }

}
