<?php

namespace Drupal\theme_selector\Form;

use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a Theme Selector Form.
 */
class ThemeSelectorForm extends EntityForm {

  /**
   * Returns list of installed themes.
   *
   * @return array
   */
  public function getInstalledThemes() {
    return \Drupal::service('theme_handler')->listInfo();
  }

  /**
   * (@inheritdoc)
   */
  public function getFormId() {
    return "theme_selector_form";
  }

  /**
   * (@inheritdoc)
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);
    // Get list of installed themes.
    $installed_themes = $this->getInstalledThemes();

    $form['title'] = [
      '#title' => t('Description'),
      '#type' => 'textfield',
      '#default_value' => $this->entity->getTitle(),
      '#size' => 25,
      '#required' => TRUE,
    ];

    $form['id'] = [
      '#type' => 'machine_name',
      '#title' => $this->t('Sufix'),
      '#default_value' => $this->entity->id(),
      '#disabled' => !$this->entity->isNew(),
      '#description' => $this->t('Unique Sufix to identify this Theme Selector.'),
      '#machine_name' => [
        'exists' => [$this, 'exist'],
      ],
    ];

    $form['theme'] = [
      '#title' => t('Name of the theme to implement'),
      '#type' => 'select',
      '#default_value' => $this->entity->getTheme(),
      '#required' => TRUE,
      '#options' => array_combine(array_keys($installed_themes), array_keys($installed_themes)),
    ];

    return $form;
  }

  /**
   * (@inheritdoc)
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $theme = $form_state->getValue('theme');
    $sufix = $form_state->getValue('sufix');
    $entity_theme = \Drupal::entityQuery('theme_selector')
      ->condition('theme', $theme)
      ->execute();

    if (!empty($entity_theme)) {
      $form_state->setErrorByName('theme', t('There already exists a sufix for this theme.',
            ['%theme' => $theme, '%sufix' => $sufix]
        ));
    }

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $status = $this->entity->save();
    $this->entity->statusMessage($status);
    $form_state->setRedirect('entity.theme_selector.list');
  }

  /**
   * Function to check whether an theme selector entity exists.
   */
  public function exist($id) {
    $entity = \Drupal::entityQuery('theme_selector')
      ->condition('id', $id)
      ->execute();
    return (bool) $entity;
  }

}
