<?php

namespace Drupal\theme_selector\Theme;

use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Theme\ThemeNegotiatorInterface;
use Drupal\theme_selector\Controller\ThemeSelectorController;

/**
 * The class ThemeNegotiator implements the ThemeNegotiatorInterface.
 */
class ThemeNegotiator implements ThemeNegotiatorInterface {

  /**
   * Validates if it is ok to apply the theme.
   *
   * @param \Drupal\Core\Routing\RouteMatchInterface $route_match
   *
   * @return bool
   */
  public function applies(RouteMatchInterface $route_match) {
    $query_theme = \Drupal::request()->query->get('theme-selector');

    if ($query_theme) {

      // Get array of possible themes to apply.
      $themeSelector = ThemeSelectorController::getThemeSelector($query_theme);
      if ($themeSelector) {
        return TRUE;
      }
    }
    return FALSE;
  }

  /**
   * This functions returns the name of the theme to be applied.
   *
   * @param \Drupal\Core\Routing\RouteMatchInterface $route_match
   *
   * @return string
   */
  public function determineActiveTheme(RouteMatchInterface $route_match) {
    // Get applyTheme and appliedTheme from session.
    $query_theme = \Drupal::request()->query->get('theme-selector');
    if ($query_theme) {
      // Get array of possible themes to apply.
      $themeSelector = ThemeSelectorController::getThemeSelector($query_theme);
      $theme = $themeSelector->getTheme();
      return $theme;

    }
  }

}
